===============================
Line Edit Widget (``lineedit``)
===============================

.. automodule:: orangecanvas.gui.lineedit

.. autoclass:: orangecanvas.gui.lineedit.LineEdit
   :members:
   :member-order: bysource
   :show-inheritance:

   .. attribute:: LeftPosition

      Left position flag

   .. attribute:: RightPosition

      Right position flag

   .. autoattribute:: triggered(QAction)
